@@ -31,9 +31,9 @@ class Normalizer():
                  train_file_path="resource/tokenizer/Bijan_khan_chunk.txt",
                  token_merger_path="resource/tokenizer/TokenMerger.pckl"):
         self.dir_path = os.path.dirname(os.path.realpath(__file__)) + "/"
-        self.dic1_path = self.dir_path + 'resource/normalizer/Dic1_new.txt'
-        self.dic2_path = self.dir_path + 'resource/normalizer/Dic2_new.txt'
-        self.dic3_path = self.dir_path + 'resource/normalizer/Dic3_new.txt'
+        self.dic1_path ='resource/normalizer/Dic1_new.txt'
+        self.dic2_path ='resource/normalizer/Dic2_new.txt'
+        self.dic3_path ='resource/normalizer/Dic3_new.txt'
         self.dic1 = self.load_dictionary(self.dic1_path)
         self.dic2 = self.load_dictionary(self.dic2_path)
         self.dic3 = self.load_dictionary(self.dic3_path)
